@@ -32,7 +32,7 @@ class OnlineSimulator():
         # overall_clicks = np.zeros((len(rankers), config.rounds))
         for i in tqdm(range(config.rounds)):
             # Select batch of n_users_per_round users
-            user_ids = np.array([dataObj.userid_mapped_data['4486'], dataObj.userid_mapped_data['4159']])#np.random.choice(range(dataObj.n_users), config.n_users_per_round, replace=False)
+            user_ids = np.random.choice(range(dataObj.n_users), config.n_users_per_round, replace=False)
             overall_optimal_reward[i] = np.take(self.optimal_rewards, user_ids).sum()
             # Iterate over all policies
             for j in range(len(self.rankers)):
@@ -125,13 +125,14 @@ class OnlineSimulator():
                             score_rel[tr] = -10000
                             break
                     coverage = AbstractRanker.ranking_coverage(dataObj.feature_data['test_item_topical_features'][ranking])
+                optimal_rankings[i] = np.asarray(ranking)
                 gain_in_topic_coverage_t = np.asarray(gain_in_topic_coverage_t)
                 delta = np.zeros((config.list_size, dataObj.feature_data['test_item_topical_features'].shape[1] + dataObj.feature_data['train_item_latent_features'].shape[1]))
                 delta[:, :dataObj.feature_data['test_item_topical_features'].shape[1]] = gain_in_topic_coverage_t
                 # self.optimal_scores[:, dataObj.feature_data['test_item_topical_features'].shape[1]:] = dataObj.feature_data['test_item_latent_features'][ranking]
                 delta[:, dataObj.feature_data['test_item_topical_features'].shape[1]:] = dataObj.feature_data['train_item_latent_features'][ranking]
                 optimal_scores[i, :] = self.user_features[i].dot(delta.T)
-                return optimal_rankings, optimal_scores
+            return optimal_rankings, optimal_scores
 
     def compute_rewards(self, config, dataObj, batch_users, rankings):
         batch_user_features = np.take(self.user_features, batch_users, axis=0)
